@@ -151,8 +151,8 @@ class CTM(object):
         for batch_samples in loader:
             # batch_size x vocab_size
             X = batch_samples['X']
+            X = X.reshape(X.shape[0], -1)
             X_bert = batch_samples['X_bert']
-
             if self.USE_CUDA:
                 X = X.cuda()
                 X_bert = X_bert.cuda()
@@ -409,3 +409,10 @@ class CTM(object):
 
         self._init_nn() #TODO implement this method
         self.model.load_state_dict(checkpoint['state_dict'])
+
+    def get_topic_word_matrix(self):
+        """
+        Return the topic-word matrix (dimensions: number of topics x length of the vocabulary).
+        If model_type is LDA, the matrix is normalized; otherwise the matrix is unnormalized.
+        """
+        return self.model.topic_word_matrix.cpu().detach().numpy()
